# frozen_string_literal: true

class Writer < BaseUser
end
